@@ -3,6 +3,7 @@ __description__ = 'sends event by email'
 
 import smtplib
 import filetype
+import platform
 
 from email.mime.text import MIMEText
 from email.mime.application import MIMEApplication
@@ -17,6 +18,8 @@ from jsonschema import validate
 
 _cfg = SimpleNamespace(host=None, port=25)
 
+hostname = platform.node()
+
 PROPERTY_MAP_SCHEMA = {
     'type': 'object',
     'properties': {
@@ -33,6 +36,9 @@ PLUGIN_PROPERTY_MAP_SCHEMA = {
     'properties': {
         'smtp-server': {
             'type': 'string',
+        },
+        'default-location': {
+            'type': 'string',
         }
     },
     'additionalProperties': False,
@@ -47,27 +53,35 @@ def load(plugin_config, **kwargs):
         logger.debug(f'{__name__} loaded, SMTP server: {_cfg.host}:{_cfg.port}')
     else:
         logger.error(f'{__name__} not active, no SMTP server provided')
+    _cfg.default_location = plugin_config.get('default-location')
 
 
-def send(config, event_id, msg, formatted_subject, sender, media, **kwargs):
+def send(config, event_id, msg, formatted_subject, sender, location, media,
+         media_fname, **kwargs):
     if _cfg.host:
         rcpt = config.get('rcpt')
-        if rcpt and sender:
+        if rcpt:
             logger.debug(f'{__name__} {event_id} sending message to {rcpt}')
-            if media:
-                m = MIMEMultipart()
-            else:
-                m = MIMEText(msg if msg is not None else '')
+            if not sender:
+                sender = 'roboger'
+            if '@' not in sender:
+                sender += '@{}'.format(location if location else (
+                    _cfg.default_location if _cfg.default_location else hostname
+                ))
+            m = MIMEMultipart() if media else MIMEText(
+                msg if msg is not None else '')
             m['Subject'] = formatted_subject
             m['From'] = sender
             m['To'] = rcpt
             if media:
                 m.attach(MIMEText(msg if msg is not None else ''))
-                ft = filetype.guess(media)
-                fname = 'attachment.txt' if ft is None else \
-                        'attachment.' + ft.extension
-                a = MIMEApplication(media, Name=fname)
-                a['Content-Disposition'] = f'attachment; filename="{fname}"'
+                if not media_fname:
+                    ft = filetype.guess(media)
+                    media_fname = 'attachment.txt' if ft is None else \
+                            f'attachment.{ft.extension}'
+                a = MIMEApplication(media, Name=media_fname)
+                a['Content-Disposition'] = (f'attachment; '
+                                            f'filename="{media_fname}"')
                 m.attach(a)
             sm = smtplib.SMTP(_cfg.host, _cfg.port)
             sm.sendmail(sender, rcpt, m.as_string())
